@@ -43,11 +43,13 @@ def get_xml_string(bpmn_graph, parameters=None):
     if parameters is None:
         parameters = {}
 
+    layout = bpmn_graph.get_layout()
+
     import xml.etree.ElementTree as ET
     from xml.dom import minidom
 
-    definitions = ET.Element("definitions")
-    definitions.set("xmlns", "http://www.omg.org/spec/BPMN/20100524/MODEL")
+    definitions = ET.Element("bpmn:definitions")
+    definitions.set("xmlns:bpmn", "http://www.omg.org/spec/BPMN/20100524/MODEL")
     definitions.set("xmlns:bpmndi", "http://www.omg.org/spec/BPMN/20100524/DI")
     definitions.set("xmlns:omgdc", "http://www.omg.org/spec/DD/20100524/DC")
     definitions.set("xmlns:omgdi", "http://www.omg.org/spec/DD/20100524/DI")
@@ -69,7 +71,7 @@ def get_xml_string(bpmn_graph, parameters=None):
                               {"bpmnElement": "id" + process, "id": "id" + str(uuid.uuid4())})
         process_planes[process] = plane
 
-        p = ET.SubElement(definitions, "process",
+        p = ET.SubElement(definitions, "bpmn:process",
                           {"id": "id" + process, "isClosed": "false", "isExecutable": "false",
                            "processType": "None"})
         process_process[process] = p
@@ -80,9 +82,9 @@ def get_xml_string(bpmn_graph, parameters=None):
         node_shape = ET.SubElement(process_planes[process], "bpmndi:BPMNShape",
                                    {"bpmnElement": node.get_id(), "id": node.get_id() + "_gui"})
         node_shape_layout = ET.SubElement(node_shape, "omgdc:Bounds",
-                                          {"height": str(node.get_height()), "width": str(node.get_width()),
-                                           "x": str(node.get_x()),
-                                           "y": str(node.get_y())})
+                                          {"height": str(layout.get(node).get_height()), "width": str(layout.get(node).get_width()),
+                                           "x": str(layout.get(node).get_x()),
+                                           "y": str(layout.get(node).get_y())})
 
     for flow in bpmn_graph.get_flows():
         process = flow.get_process()
@@ -90,7 +92,7 @@ def get_xml_string(bpmn_graph, parameters=None):
         flow_shape = ET.SubElement(process_planes[process], "bpmndi:BPMNEdge",
                                    {"bpmnElement": "id" + str(flow.get_id()),
                                     "id": "id" + str(flow.get_id()) + "_gui"})
-        for x, y in flow.get_waypoints():
+        for x, y in layout.get(flow).get_waypoints():
             waypoint = ET.SubElement(flow_shape, "omgdi:waypoint", {"x": str(x), "y": str(y)})
 
     for node in bpmn_graph.get_nodes():
@@ -99,36 +101,42 @@ def get_xml_string(bpmn_graph, parameters=None):
         if isinstance(node, BPMN.StartEvent):
             isInterrupting = "true" if node.get_isInterrupting() else "false"
             parallelMultiple = "true" if node.get_parallelMultiple() else "false"
-            task = ET.SubElement(process, "startEvent",
+            task = ET.SubElement(process, "bpmn:startEvent",
                                  {"id": node.get_id(), "isInterrupting": isInterrupting, "name": node.get_name(),
                                   "parallelMultiple": parallelMultiple})
         elif isinstance(node, BPMN.EndEvent):
-            task = ET.SubElement(process, "endEvent", {"id": node.get_id(), "name": node.get_name()})
-        elif isinstance(node, BPMN.OtherEvent):
-            task = ET.SubElement(process, node.type, {"id": node.get_id(), "name": node.get_name()})
+            task = ET.SubElement(process, "bpmn:endEvent", {"id": node.get_id(), "name": node.get_name()})
+        elif isinstance(node, BPMN.IntermediateCatchEvent):
+            task = ET.SubElement(process, "bpmn:intermediateCatchEvent", {"id": node.get_id(), "name": node.get_name()})
+        elif isinstance(node, BPMN.IntermediateThrowEvent):
+            task = ET.SubElement(process, "bpmn:intermediateThrowEvent", {"id": node.get_id(), "name": node.get_name()})
+        elif isinstance(node, BPMN.BoundaryEvent):
+            task = ET.SubElement(process, "bpmn:boundaryEvent", {"id": node.get_id(), "name": node.get_name()})
         elif isinstance(node, BPMN.Task):
-            task = ET.SubElement(process, node.type, {"id": node.get_id(), "name": node.get_name()})
+            task = ET.SubElement(process, "bpmn:task", {"id": node.get_id(), "name": node.get_name()})
+        elif isinstance(node, BPMN.SubProcess):
+            task = ET.SubElement(process, "bpmn:subProcess", {"id": node.get_id(), "name": node.get_name()})
         elif isinstance(node, BPMN.ExclusiveGateway):
-            task = ET.SubElement(process, "exclusiveGateway",
-                                 {"id": node.get_id(), "gatewayDirection": node.get_gatewayDirection(),
+            task = ET.SubElement(process, "bpmn:exclusiveGateway",
+                                 {"id": node.get_id(), "gatewayDirection": node.get_gateway_direction().value.lower(),
                                   "name": ""})
         elif isinstance(node, BPMN.ParallelGateway):
-            task = ET.SubElement(process, "parallelGateway",
-                                 {"id": node.get_id(), "gatewayDirection": node.get_gatewayDirection(),
+            task = ET.SubElement(process, "bpmn:parallelGateway",
+                                 {"id": node.get_id(), "gatewayDirection": node.get_gateway_direction().value.lower(),
                                   "name": ""})
         elif isinstance(node, BPMN.InclusiveGateway):
-            task = ET.SubElement(process, "inclusiveGateway",
-                                 {"id": node.get_id(), "gatewayDirection": node.get_gatewayDirection(),
+            task = ET.SubElement(process, "bpmn:inclusiveGateway",
+                                 {"id": node.get_id(), "gatewayDirection": node.get_gateway_direction().value.lower(),
                                   "name": ""})
         else:
             raise Exception("Unexpected node type.")
 
         for in_arc in node.get_in_arcs():
-            arc_xml = ET.SubElement(task, "incoming")
+            arc_xml = ET.SubElement(task, "bpmn:incoming")
             arc_xml.text = "id" + str(in_arc.get_id())
 
         for out_arc in node.get_out_arcs():
-            arc_xml = ET.SubElement(task, "outgoing")
+            arc_xml = ET.SubElement(task, "bpmn:outgoing")
             arc_xml.text = "id" + str(out_arc.get_id())
 
     for flow in bpmn_graph.get_flows():
@@ -136,7 +144,7 @@ def get_xml_string(bpmn_graph, parameters=None):
 
         source = flow.get_source()
         target = flow.get_target()
-        flow_xml = ET.SubElement(process, "sequenceFlow", {"id": "id" + str(flow.get_id()), "name": flow.get_name(),
+        flow_xml = ET.SubElement(process, "bpmn:sequenceFlow", {"id": "id" + str(flow.get_id()), "name": flow.get_name(),
                                                            "sourceRef": str(source.get_id()),
                                                            "targetRef": str(target.get_id())})
 
