@@ -14,10 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from copy import deepcopy
-
-from pm4py.objects.log.obj import EventLog
+from pm4py.objects.log.obj import EventLog, Trace, EventStream
 from pm4py.util import xes_constants as xes
+from pm4py.objects.conversion.log import converter as log_converter
 
 
 def sort_timestamp_trace(trace, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse_sort=False):
@@ -38,8 +37,8 @@ def sort_timestamp_trace(trace, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse
     trace
         Sorted trace
     """
-    new_trace = deepcopy(trace)
-    new_trace._list.sort(key=lambda x: x[timestamp_key], reverse=reverse_sort)
+    events = sorted(trace._list, key=lambda x: x[timestamp_key], reverse=reverse_sort)
+    new_trace = Trace(events, attributes=trace.attributes)
     return new_trace
 
 
@@ -61,18 +60,20 @@ def sort_timestamp_stream(event_log, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, re
     event_log
         Sorted event log
     """
-    new_event_log = deepcopy(event_log)
-    new_event_log._list.sort(key=lambda x: x[timestamp_key], reverse=reverse_sort)
-    return new_event_log
+    events = sorted(event_log._list, key=lambda x: x[timestamp_key], reverse=reverse_sort)
+    new_stream = EventStream(events, attributes=event_log.attributes, extensions=event_log.extensions,
+                             omni_present=event_log.omni_present, classifiers=event_log.classifiers,
+                             properties=event_log.properties)
+    return new_stream
 
 
-def sort_timestamp_log(log, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse_sort=False):
+def sort_timestamp_log(event_log, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse_sort=False):
     """
     Sort a log based on timestamp key
 
     Parameters
     -----------
-    log
+    event_log
         Log
     timestamp_key
         Timestamp key
@@ -84,12 +85,14 @@ def sort_timestamp_log(log, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse_sor
     log
         Sorted log
     """
-    new_log = deepcopy(log)
-    new_log._list = [x for x in new_log._list if len(x) > 0]
-    for i in range(len(new_log._list)):
-        new_log._list[i] = sort_timestamp_trace(new_log._list[i], timestamp_key=timestamp_key,
-                                                      reverse_sort=reverse_sort)
+    event_log = log_converter.apply(event_log, variant=log_converter.Variants.TO_EVENT_LOG)
 
+    new_log = EventLog(attributes=event_log.attributes, extensions=event_log.extensions,
+                       omni_present=event_log.omni_present, classifiers=event_log.classifiers,
+                       properties=event_log.properties)
+    for trace in event_log:
+        if trace:
+            new_log.append(sort_timestamp_trace(trace, timestamp_key=timestamp_key, reverse_sort=reverse_sort))
     new_log._list.sort(key=lambda x: x[0][timestamp_key], reverse=reverse_sort)
 
     return new_log
@@ -118,13 +121,13 @@ def sort_timestamp(log, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY, reverse_sort=Fa
     return sort_timestamp_stream(log, timestamp_key=timestamp_key, reverse_sort=reverse_sort)
 
 
-def sort_lambda_log(log, sort_function, reverse=False):
+def sort_lambda_log(event_log, sort_function, reverse=False):
     """
     Sort a log based on a lambda expression
 
     Parameters
     ------------
-    log
+    event_log
         Log
     sort_function
         Sort function
@@ -136,19 +139,23 @@ def sort_lambda_log(log, sort_function, reverse=False):
     new_log
         Sorted log
     """
-    new_log = deepcopy(log)
-    new_log._list.sort(key=sort_function, reverse=reverse)
+    event_log = log_converter.apply(event_log, variant=log_converter.Variants.TO_EVENT_LOG)
+
+    traces = sorted(event_log._list, key=sort_function, reverse=reverse)
+    new_log = EventLog(traces, attributes=event_log.attributes, extensions=event_log.extensions,
+                       omni_present=event_log.omni_present, classifiers=event_log.classifiers,
+                       properties=event_log.properties)
 
     return new_log
 
 
-def sort_lambda_stream(stream, sort_function, reverse=False):
+def sort_lambda_stream(event_log, sort_function, reverse=False):
     """
     Sort a stream based on a lambda expression
 
     Parameters
     ------------
-    stream
+    event_log
         Stream
     sort_function
         Sort function
@@ -160,10 +167,12 @@ def sort_lambda_stream(stream, sort_function, reverse=False):
     stream
         Sorted stream
     """
-    new_event_log = deepcopy(stream)
-    new_event_log._list.sort(key=sort_function, reverse=reverse)
+    events = sorted(event_log._list, key=sort_function, reverse=reverse)
+    new_stream = EventStream(events, attributes=event_log.attributes, extensions=event_log.extensions,
+                             omni_present=event_log.omni_present, classifiers=event_log.classifiers,
+                             properties=event_log.properties)
 
-    return new_event_log
+    return new_stream
 
 
 def sort_lambda(log, sort_function, reverse=False):
