@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.visualization.align_table import visualizer
+
+import warnings
+
+warnings.warn("The align_table visualizer will be removed in a future release.")
